<?php
 
/*-----------------------------------------------------------------------------------*/
/* Provides a notification to the user everytime 
/* your WordPress theme is updated  
/*-----------------------------------------------------------------------------------*/



// Constants for the theme name, folder and remote XML url
define( 'NOTIFIER_THEME_NAME', THEME_NAME_Fa ); // The theme name
define( 'NOTIFIER_THEME_FOLDER_NAME', Theme_Folder ); // The theme folder name
define( 'NOTIFIER_XML_FILE', 'http://www.mahdisweb.net/themes/' . Theme_Folder . '/notifier.xml' ); // The remote notifier XML file containing the latest version of the theme and changelog
define( 'NOTIFIER_CACHE_INTERVAL', 21600 ); // The time interval for the remote XML cache in the database (21600 seconds = 6 hours)

// Adds an update notification to the WordPress Dashboard menu
function update_notifier_menu() {
	if (function_exists('simplexml_load_string')) { // Stop if simplexml_load_string funtion isn't available
	    $xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); // Get the latest remote XML file on our server
		$theme_data = wp_get_theme();
		$theme_version = $theme_data->get( 'Version' );

		if( (float)$xml->latest > (float)$theme_version) { // Compare current theme version with the remote XML version
			add_theme_page( NOTIFIER_THEME_NAME . ' Theme Updates', NOTIFIER_THEME_NAME . ' <span class="update-plugins count-1"><span class="update-count">جدید</span></span>', 'administrator', 'theme-update-notifier', 'update_notifier');
		}
	
	}
}
add_action('admin_menu', 'update_notifier_menu');



// Adds an update notification to the WordPress 3.1+U0NSSVBUWUFCLkNPTQ Admin Bar 
function update_notifier_bar_menu() {
	if (function_exists('simplexml_load_string')) { // Stop if simplexml_load_string funtion isn't available
		global $wp_admin_bar, $wpdb;

		if ( !is_super_admin() || !is_admin_bar_showing() ) // Don't display notification in admin bar if it's disabled or the current user isn't an administrator
		return;

		$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); // Get the latest remote XML file on our server
		$theme_data = wp_get_theme();
		$theme_version = $theme_data->get( 'Version' );

		if( (float)$xml->latest > (float)$theme_version) { // Compare current theme version with the remote XML version
			$wp_admin_bar->add_menu( array( 'id' => 'update_notifier', 'title' => '<span>' . NOTIFIER_THEME_NAME . ' <span id="ab-updates">آپدیت جدید</span></span>', 'href' => get_admin_url() . 'themes.php?page=theme-update-notifier' ) );
		}
	}
}
add_action( 'admin_bar_menu', 'update_notifier_bar_menu', 1000 );



// The notifier page
function update_notifier() {
	$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); // Get the latest remote XML file on our server
	$theme_data = wp_get_theme();
	$theme_version = $theme_data->get( 'Version' );
	$themecreate_url = 'http://www.mahdisweb.net/';
	?>

	<style>
	    #wpadminbar .quicklinks a span#ab-updates{	font-weight:normal; 	padding: 1px 7px 3px;    font-size: 11px;}
		.update-nag { display: none; }
		#instructions {max-width: 100%;    min-height: 300px;}
		.uptit,h3.title { font-family:Tahoma !important; margin: 30px 0 0 0; padding: 30px 0 0 0; border-top: 1px solid #ddd; font-weight:normal !important}
	</style>

	<div class="wrap">

		<div id="icon-tools" class="icon32"></div>
		<h2 class="uptit"> بروزرسانی پوسته <?php echo NOTIFIER_THEME_NAME ?></h2>
	    <div id="message" class="updated below-h2"><p><strong>نگارش تازه ای از پوسته <?php echo NOTIFIER_THEME_NAME; ?> آماده شده است.</strong> شما از نگارش <?php echo $theme_version; ?> استفاده می‌کنید. به نگارش <?php echo $xml->latest; ?> ارتقا دهید.</p></div>
	    


		

		<div id="instructions">
        <img style="float: left; margin:15px 20px 20px 0; border: 1px solid #ddd;" src="<?php echo get_template_directory_uri() . '/screenshot.png'; ?>" />
		    <h3 class="uptit">نحوه ی دریافت و بروزرسانی پوسته</h3>
		    <p><strong>توجه:</strong> قبل از هرگونه عملیاتی از پوشه ای که پوسته در آن نصب شده بکاپ بگیرید.</p>
            <p><strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</strong></p>
            <p>برای این کار ابتدا آخرین نگارش پوسته موجود را از پنل کاربری <a href="<?php echo $themecreate_url; ?>">ماهدیس وب</a> دریافت کنید:</p>
            <p>سپس فایل زیپ دانلود شده را بر روی هارد کامپیوتر خود Extract نمایید.</p>
            <p>با استفاده از نرم افزار  FTP Manager و یا فایل منیجر سی پنل هاست فایل ها را به درون پوشه ای که در مسیر زیر نوشته شده انتقال دهید</p>
		    <p>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</p>
		   
		</div>

	    <h3 class="title">لیست تغییرات</h3>
	    <?php echo $xml->changelog; ?>

	</div>

<?php }



// Get the remote XML file contents and return its data (Version and Changelog)
// Uses the cached version if available and inside the time interval defined
function get_latest_theme_version($interval) {
	$notifier_file_url = NOTIFIER_XML_FILE;
	$db_cache_field = Theme_Folder . '-notifier-cache';
	$db_cache_field_last_updated = Theme_Folder . '-notifier-cache-last-updated';
	$last = get_option( $db_cache_field_last_updated );
	$now = time();
	// check the cache
	if ( !$last || (( $now - $last ) > $interval) ) {
		// cache doesn't exist, or is old, so refresh it

		$cache = '';
		$response = wp_remote_get($notifier_file_url);
		if (!is_wp_error($response)) {
			$cache = $response['body'];
		}

		if ($cache) {
			// we got good results
			update_option( $db_cache_field, $cache );
			update_option( $db_cache_field_last_updated, time() );
		}
		// read from the cache file
		$notifier_data = get_option( $db_cache_field );
	}
	else {
		// cache file is fresh enough, so read from it
		$notifier_data = get_option( $db_cache_field );
	}

	// Let's see if the $xml data was returned as we expected it to.
	// If it didn't, use the default 1.0 as the latest version so that we don't have problems when the remote server hosting the XML file is down
	if( strpos((string)$notifier_data, '<notifier>') === false ) {
		$notifier_data = '<?xml version="1.0" encoding="UTF-8"?><notifier><latest>1.0</latest><changelog></changelog></notifier>';
	}

	// Load the remote XML data into a variable and return it
	$xml = simplexml_load_string($notifier_data);

	return $xml;
}
